MixBetaDens generates the pdf and cdf of a mixture of beta functions, and calculates the area under the graph between two points.
MixBetaDens(
n,
p,
x = seq(0, 15, by = 0.01),
a = 0,
b = 1,
n_g = n_g,
var = var
)MixBetaDens returns a list with
The probability density at each x value
The cumulative density at each x value
The area under the pdf graph between a and b
The number of observations in the dataset
The dimension
A vector of x values to evaluate. Default value is seq(0, 15, by=0.01)
Lower bound for area evaluation. Default value is 0
Upper bound for area evaluation. Default value is 1
Vector describing the number of observations in each cluster
A list of cluster variance matrices
The domain for this function is not [0,1] as is typical with a beta function. The domain encompasses the shifted log-likelihoods generated in oclust.